<script setup>
import { ref , onMounted } from "vue";
import { setActmBattCount, setActmBattCountPl } from "./api";
import useElement from "@/hooks/useElement.js";
const { $alert, $loading, $message, $confirm } = useElement();

const $emit = defineEmits(["update:model-value"]);

const battCount = ref(0);
const props = defineProps({
  modelValue: {
    type: Boolean,
    required: true,
  },
  devs: {
    type: [Object, Array],
    required: true,
  },
  isBatch: {
    type: Boolean,
    default: false,
  },
  isOnlyOne: {
    type: Boolean,
    default: false,
  }
});

function close() {
  $emit("update:model-value", false);
}

function setCount() {
  if (props.isBatch) {
    setCountBatch();
  } else {
    setCountOne();
  }
}

function setCountOne() {
  let loading = $loading();
  setActmBattCount(battCount.value, props.devs.devId)
    .then((res) => {
      loading.close();
      let { code, data, msg } = res.data;
      if (200 == code) {
        $message.success("操作成功");
        // console.log(data);
        close();
      } else {
        $message.error("操作失败:" + msg);
      }
    })
    .catch((err) => {
      loading.close();
      $message.error("操作失败:" + err);
      console.log(err);
    });
}

function setCountBatch() {
   let loading = $loading();
  setActmBattCountPl(battCount.value, props.devs.map((v) => v.devId))
    .then((res) => {
      let { code, data, data2 } = res.data;
      loading.close();
      let failList = [];
      let successList = [];
      Object.keys(data2).forEach((v) => {
        if (200 == data2[v].code) {
          successList.push(v);
        } else {
          failList.push(v);
        }
      });

      if (code && data && successList.length) {
        $message.success("操作成功");
        if (failList.length) {
          let failNames = props.devs
            .filter((v) => failList.some((vv) => vv == v.devId))
            .map((v) => v.devIdcode);

          $alert(`操作失败的设备列表：${failNames.join(", ")}。`);
        }
        close();
      } else {
        $message.error("操作失败");
      }
    })
    .catch((err) => {
      loading.close();
      $message.error("操作失败");
      console.log(err);
    });
}

onMounted(() => {
  battCount.value = props.isOnlyOne ? 0 : 1;
})
</script>

<template>
  <!-- <el-select v-model="battCount">
    <el-option
      label="1组, 每组24节单体"
      :value="0"
    />
    <el-option
      label="2组, 每组12节单体"
      :value="1"
    />
  </el-select> -->
  <el-radio-group class="radio-group" v-model="battCount">
    <el-radio :value="0">1组, 每组24节单体</el-radio>
    <el-radio :value="1">2组, 每组12节单体</el-radio>
  </el-radio-group>
  <div class="footer">
    <el-button @click="close">取消</el-button>
    <el-button type="primary" @click="setCount">确定</el-button>
  </div>
</template>

<style scoped lang="less">
.radio-group {
  display: flex;
  flex-direction: column;
  :deep(label) {
    margin-right: 0;
  }
}
.footer {
  text-align: right;
}
</style>
